@@ -4,7 +4,7 @@
 /*                                                              */
 /* Main Routine                                                 */
 /****************************************************************/
-/* bgpview.c,v 1.51 2002/04/12 08:15:08 kuniaki Exp */
+/* bgpview.c,v 1.3 2004/03/01 12:49:55 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2002 Internet Initiative Japan Inc.
@@ -32,6 +32,11 @@
  * DISCLAIMED.
  */
 
+/*
+ * Copyright (c) 2003 Intec NetCore, Inc.
+ * All rights reserved.
+ */
+
 #include "bgp.h"
 
 #ifdef sun
@@ -921,6 +926,25 @@ int execoption(int opcn, char *val[])
 	return(ret);
 }
 
+int connect_waiting()
+{
+        int     ret;
+        int     cnt;
+
+        ret = 0;
+        for(cnt = 0; cnt < MAXPEERS && peer[cnt].neighbor != 0; cnt++) {
+                if (peer[cnt].status == CONNECT) {
+#ifdef DEBUG
+        printf("DEBUG: NON-BLOCKING FOR CONNECT STATUS\n");
+#endif
+                        ret = 1;
+                        break;
+                }
+        }
+        return(ret);
+}
+
+
 main(int argc, char *argv[])
 {
 	int			fromlen;
@@ -1026,6 +1050,11 @@ main(int argc, char *argv[])
 				timer_value.tv_sec  = 0;
 				timer_value.tv_usec = 0;
 			}
+			if (connect_waiting() == 1) {
+				timer_value.tv_sec  = 0;
+				timer_value.tv_usec = 0;
+			}
+				
 			resetfds();
 			nfd = select(FD_SETSIZE, &readfds, 
 						NULL, NULL, &timer_value);
@@ -1235,16 +1264,11 @@ main(int argc, char *argv[])
 			    }
 			}
 
-			if (FD_ISSET(peer[pn].soc, &readfds)) {
-#if 0
-				pr_log(VLOG_GLOB, pn,
-					"Client Socket Receive\n", ON);
-#endif
-				if (peer[pn].status == CONNECT) {
-					fcntl(peer[pn].soc, F_SETFL,
-						peer[pn].flag);
-					peer[pn].event = BGP_TRANS_CNT_OPEN;
-				} else {
+			if (peer[pn].status == CONNECT) {
+				fcntl(peer[pn].soc, F_SETFL, peer[pn].flag);
+				peer[pn].event = BGP_TRANS_CNT_OPEN;
+			} else {
+				if (FD_ISSET(peer[pn].soc, &readfds)) {
 					check_header(pn);
 				}
 			}
