@@ -3,7 +3,7 @@
 /*                                                              */
 /* BGPView Shell Commands                                       */
 /****************************************************************/
-/* bvcommand.c,v 1.57 2002/04/13 00:31:27 kuniaki Exp */
+/* bvcommand.c,v 1.1 2003/03/31 05:51:04 kuniaki Exp */
 
 /*
  * Copyright (c) 2000 - 2001 Internet Initiative Japan Inc.
@@ -822,7 +822,7 @@ int bvc_doannouncedummy(BVS_CMD_PARAM *prm)
 		bvs_write(clno, "Target Peer is not Established\r\n");
 		break;
 	case 3:
-		bvs_write(clno, "Now Actioning\r\n");
+		bvs_write(clno, "Now Sending\r\n");
 		break;
 	case 4:
 		bvs_write(clno, "Dump File Not Configured\r\n");
