@@ -28,7 +28,12 @@
 # DISCLAIMED.
 #
 
-$ORIGINAS = 2497;
+#
+# Copyright (c) 2003 Intec NetCore, Inc.
+# All rights reserved.
+#
+
+$ORIGINAS = 18146;
 
 sub checkas {
 	local($oneline) = @_;
@@ -109,7 +114,9 @@ sub checkas {
 	$nflag		= 0;
 	$unreal		= 0;
 	$unstablenew    = 0;
-	$pathlength	= 0;
+	@pathl_sd	= ();
+	$ptc 		= -1;
+	@ptotal		= ();
 
 	@originroute = ();
 	@oasupdate = ();
@@ -126,6 +133,8 @@ sub checkas {
 		next if (/AS_Path/);
 		chomp;
 		if (/==\ Prefix\ Update\ History\ /) {
+			$ptc++;
+			$ptotal[$ptc] = 0;
 			# Flapped Route
 			$updated++;
 			$eachplen[$lstack]++;
@@ -150,12 +159,14 @@ sub checkas {
 			@data2 = split(/:/, $data[2]);
 			$etimecnt[$data2[0]]++;
 			$oaswithdraw[$oas]++;
+			$ptotal[$ptc]++;
 		} elsif (/UPDATE/) {
 			$totalupdate++;
 			@data = split(/\s+/, $_);
 			@data2 = split(/:/, $data[2]);
 			$etimecnt[$data2[0]]++;
 			$oasupdate[$oas]++;
+			$ptotal[$ptc]++;
 		} else {
 			$total++;
 			if ($nflag == 1) {
@@ -176,6 +187,7 @@ sub checkas {
 				$withdrawed++;
 				$actflg = 0;
 			} else {
+				$pathl_sd[$active] = $pathl;
 				$active++;
 				if (/:/) {
 					$nflag = 1;
@@ -185,7 +197,6 @@ sub checkas {
 				$actflg = 1;
 				$origintype[$otype]++;
 				$originroute[$oas]++;
-				$pathlength += $pathl;
 			}
 			@data = split(/\s+/, $_);
 			@data2 = split(/\//, $data[1]);
@@ -207,6 +218,10 @@ sub checkas {
 	@oastotalup = ();
 	$cnt = 0;
 	while(!defined($oasupdate[$cnt])) {
+		if ($cnt >= 70000) {
+			print "Data Illegal\n";
+			exit;
+		}
 		if (!defined($oasupdate[$cnt])) {
 			$cnt++;
 			next;
@@ -233,7 +248,7 @@ sub checkas {
 				undef($temp1);
 				undef($temp2);
 				$astemp = $cnt;
-				$ttemp = $temptotal;;
+				$ttemp = $temptotal;
 				while(defined($oastotalup[$cnt1])) {
 					if (defined($temp1)) {
 						$ttemp = $temp1;
@@ -281,14 +296,40 @@ sub checkas {
 		printf(" Incresed Routes       : %7d routes\n",
 				($unstablenew+$adaynew) - ($withdrawed-$unreal));
 	}
+
+	# Calc Changes Info
+	$min = $ptotal[0];
+	$max = $ptotal[0];
+	$cnt = 0;
+	$totalchn = 0;
+	while(defined($ptotal[$cnt])) {
+		$totalchn += $ptotal[$cnt];
+		$min = $ptotal[$cnt] if ($min > $ptotal[$cnt]);
+		$max = $ptotal[$cnt] if ($max < $ptotal[$cnt]);
+		$cnt++;
+	}
+	$upd_avg = $totalchn / $updated;
+	$cnt = 0;
+	$sd = 0;
+	while(defined($ptotal[$cnt])) {
+		$sd += ($ptotal[$cnt] - $upd_avg)**2;
+		$cnt++;
+	}
+	$psd = sqrt($sd / $updated);
+	
+
 	printf(" Total Updated Route   : %7d routes\n",$updated);
 	printf(" Updated Still Active  : %7d routes\n", $updated-$withdrawed);
 	printf(" Total Update Times    : %7d times\n",$totalupdate);
 	printf(" Total Withdraw Times  : %7d times\n",$totalwithdraw);
 	printf(" Total Changes         : %7d times\n",
 						 $totalupdate+$totalwithdraw);
-	printf("               Average : %7.1f times/updated route\n",
-					($totalupdate+$totalwithdraw)/$updated);
+#	printf("               Average : %7.1f times/updated route\n",
+#					($totalupdate+$totalwithdraw)/$updated);
+	printf("               Average : %7.1f times/updated route\n", $upd_avg);
+	printf("                            Max : %7.1f times\n", $max);
+	printf("		            Min : %7.1f times\n", $min);
+	printf("                            SD  : %7.1f\n", $psd);
 	print "\n";
 
 	printf(" AS Path Analysis\n");
@@ -297,7 +338,30 @@ sub checkas {
 	printf("   EGP Route           : %7d routes\n", $origintype[3]);
 	printf("   Num. of origin AS   : %7d origins\n", $norg);
 	printf("   Num. of Route per AS: %5.1f routes\n", $active/$norg);
-	printf("   AS Path length avg. : %5.1f\n", $pathlength/$active);
+
+	# Calc Min/Avg/Max/SD
+	$min = $pathl_sd[0];
+	$max = $pathl_sd[0];
+	$total_lenght = 0;
+	$cnt=0;
+	while(defined($pathl_sd[$cnt])) {
+		$total_length += $pathl_sd[$cnt];
+		$min = $pathl_sd[$cnt] if ($min > $pathl_sd[$cnt]);
+		$max = $pathl_sd[$cnt] if ($max < $pathl_sd[$cnt]);
+		$cnt++;
+	}
+	$pathl_avg = $total_length / $active;
+	$sd = 0;
+	$cnt = 0;
+	while(defined($pathl_sd[$cnt])) {
+		$sd += ($pathl_sd[$cnt]-$pathl_avg)**2;
+		$cnt++;
+	}
+	$psd = sqrt($sd / $active);
+	printf("   AS Path length avg. : %5.1f\n", $pathl_avg);
+	printf("                            Max : %5.1f\n", $max);
+	printf("                            Min : %5.1f\n", $min);
+	printf("                            SD  : %5.1f\n", $psd);
 	printf("\n");
 
 
