@@ -4,7 +4,7 @@
 /*                                                              */
 /* Routeing Information Update Routine                          */
 /****************************************************************/
-/* update.c,v 1.29 2002/04/19 05:37:44 kuniaki Exp */
+/* update.c,v 1.1 2003/03/31 05:51:04 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -284,6 +284,14 @@ void pr_update(int pn)
 	le1 = length;
 	sprintf(logstr, "Unfeasible Route Length = %d octets\n", length);
 	pr_log(VLOG_UPDE, pn, logstr, OFF);
+
+	/* Length Check */
+	if ((peer[pn].datalen - 4) < length) {
+		/* Unfeasible Route Length Error */
+		pr_log(VLOG_UPDE, pn, "!!! Unfeasible Route Length Error.\n", OFF);
+		return;
+	}
+
 	ptr += 2;
 	pt2 = 0;
 	if (length == 0) {
@@ -811,7 +819,7 @@ void pr_update(int pn)
 
 			v6prroute.length = listbuf->length;
 
-			if (prroute.length > (IPV6_ADDR_LEN*8)) {
+			if (v6prroute.length > (IPV6_ADDR_LEN*8)) {
 				pt2++;
 				pr_log(VLOG_UPDE, pn, "IPv6 Prefix too long.\n", OFF);
 				continue;
